@@ -57,6 +57,7 @@ from harlequin.catalog_cache import (
 from harlequin.components import (
     CodeEditor,
     DataCatalog,
+    DebugInfoScreen,
     EditorCollection,
     ErrorModal,
     ExportScreen,
@@ -69,6 +70,12 @@ from harlequin.components import (
 from harlequin.components.confirm_modal import ConfirmModal
 from harlequin.components.data_catalog import ContextMenu
 from harlequin.components.data_catalog.tree import HarlequinTree
+from harlequin.components.debug_info import AdapterDebugInfo, HarlequinDebugInfo
+from harlequin.config import (
+    get_config_for_profile,
+    get_highest_priority_existing_config_file,
+    load_config,
+)
 from harlequin.copy_formats import HARLEQUIN_COPY_FORMATS, WINDOWS_COPY_FORMATS
 from harlequin.driver import HarlequinDriver
 from harlequin.editor_cache import BufferState, Cache
@@ -182,6 +189,7 @@ class Harlequin(AppBase):
     def __init__(
         self,
         adapter: HarlequinAdapter,
+        profile_name: str | None = None,
         *,
         keymap_names: Sequence[str] | None = None,
         user_defined_keymaps: Sequence[HarlequinKeyMap] | None = None,
@@ -201,6 +209,7 @@ class Harlequin(AppBase):
             watch_css=watch_css,
         )
         self.adapter = adapter
+        self.profile_name = profile_name
         self.connection_hash = connection_hash
         self.history: History | None = None
         self.show_files = show_files
@@ -279,6 +288,8 @@ class Harlequin(AppBase):
             and self.editor._has_focus_within
         ):
             self.editor.text_input._pause_blink(visible=True)
+
+        ## TODO: PREVENT DUPLICATE SCREENS HERE.
         return super().push_screen(  # type: ignore[no-any-return,call-overload]
             screen,
             callback=callback,
@@ -951,6 +962,47 @@ class Harlequin(AppBase):
     def action_show_help_screen(self) -> None:
         self.push_screen(HelpScreen(id="help_screen"))
 
+    def action_show_debug_info(self) -> None:
+        SCREEN_ID = "debug_info_screen"
+        if self.screen.id == SCREEN_ID:
+            # already showing this screen.
+            return
+
+        config_path = get_highest_priority_existing_config_file()
+        config = load_config(config_path)
+        profile_name = self.profile_name
+        active_profile_config, _ = get_config_for_profile(config_path, profile_name)
+        active_profile_name = profile_name or config.get("default_profile")
+        adapter_options = getattr(self.adapter, "ADAPTER_OPTIONS", None)
+        adapter_type = type(self.adapter).__name__
+
+        harlequin_info = HarlequinDebugInfo(
+            active_profile_config=active_profile_config,
+            active_profile_name=active_profile_name,
+            all_keymaps=list(self.all_keymaps.keys()),
+            config=config,
+            config_path=config_path,
+            keymap_names=self.keymap_names,
+            theme=self.theme,
+        )
+        adapter_info = AdapterDebugInfo(
+            adapter_options=adapter_options,
+            adapter_type=adapter_type,
+            adapter_details=self.adapter.ADAPTER_DETAILS
+            if self.adapter.provides_details
+            else "No details were provided by adapter.",
+            adapter_driver_details=self.adapter.ADAPTER_DRIVER_DETAILS
+            if self.adapter.provides_driver_details
+            else "No details were provided by the database driver.",
+        )
+        self.push_screen(
+            DebugInfoScreen(
+                harlequin_details=harlequin_info.parse_info(),
+                adapter_details=adapter_info.parse_info(),
+                id=SCREEN_ID,
+            )
+        )
+
     def action_toggle_full_screen(self) -> None:
         self.full_screen = not self.full_screen
 
